@@ -21,6 +21,7 @@
 -- * <https://tools.ietf.org/html/rfc8103 RFC 8103>: Using ChaCha20-Poly1305 Authenticated Encryption in the Cryptographic Message Syntax (CMS)
 -- * <https://tools.ietf.org/html/rfc8418 RFC 8418>: Use of the Elliptic Curve Diffie-Hellman Key Agreement Algorithm with X25519 and X448 in the Cryptographic Message Syntax (CMS)
 -- * <https://tools.ietf.org/html/rfc8419 RFC 8419>: Use of Edwards-Curve Digital Signature Algorithm (EdDSA) Signatures in the Cryptographic Message Syntax (CMS)
+-- * <https://tools.ietf.org/html/rfc8702 RFC 8702>: Use of the SHAKE One-Way Hash Functions in the Cryptographic Message Syntax (CMS)
 {-# LANGUAGE RecordWildCards #-}
 module Crypto.Store.CMS
     ( ContentType(..)
@@ -60,6 +61,7 @@ module Crypto.Store.CMS
     , KeyEncryptionParams(..)
     , KeyTransportParams(..)
     , KeyAgreementParams(..)
+    , KeyAgreementKDF(..)
     , RecipientInfo(..)
     , EnvelopedData(..)
     , ProducerOfRI
@@ -144,6 +146,10 @@ module Crypto.Store.CMS
     , findAttribute
     , setAttribute
     , filterAttributes
+    -- * CMS standard attributes
+    , getSigningTimeAttr
+    , setSigningTimeAttr
+    , setSigningTimeAttrCurrent
     -- * Originator information
     , OriginatorInfo(..)
     , CertificateChoice(..)
@@ -158,7 +164,7 @@ import Data.ASN1.BinaryEncoding
 import Data.ASN1.Encoding
 import Data.ByteString (ByteString)
 import Data.Maybe (isJust)
-import Data.List (nub, unzip3)
+import Data.List (nub)
 
 import Crypto.Hash
 
