@@ -1,3 +1,4 @@
+{-# LANGUAGE OverloadedStrings #-}
 {-# OPTIONS_GHC -fno-warn-orphans #-}
 -- | Orphan instances.
 module CMS.Instances
@@ -154,7 +155,12 @@ arbitraryIntegrityDigest = elements
     ]
 
 instance Arbitrary MACAlgorithm where
-    arbitrary = (\(DigestAlgorithm alg) -> HMAC alg) <$> arbitraryIntegrityDigest
+    arbitrary = oneof
+        [ (\(DigestAlgorithm alg) -> HMAC alg) <$> arbitraryIntegrityDigest
+        , (\(SomeNat p) -> KMAC_SHAKE128 p) <$> arbitraryNat <*> arbitraryCtx
+        , (\(SomeNat p) -> KMAC_SHAKE256 p) <$> arbitraryNat <*> arbitraryCtx
+        ]
+      where arbitraryCtx = elements [ B.empty , "ctx" , "custom string" ]
 
 instance Arbitrary OAEPParams where
     arbitrary = do
@@ -377,19 +383,24 @@ instance Arbitrary KeyIdentifier where
 arbitraryAgreeParams :: Bool -> KeyEncryptionParams -> Gen KeyAgreementParams
 arbitraryAgreeParams allowCofactorDH alg
     | allowCofactorDH = oneof
-        [ flip StdDH alg <$> arbitraryDigest
-        , flip CofactorDH alg <$> arbitraryDigest
+        [ flip StdDH alg <$> elements stdKDFs
+        , flip CofactorDH alg <$> elements cofactorKDFs
         ]
-    | otherwise = flip StdDH alg <$> arbitraryDigest
+    | otherwise = flip StdDH alg <$> elements stdKDFs
   where
-    arbitraryDigest =
-        elements
-            [ DigestAlgorithm SHA1
-            , DigestAlgorithm SHA224
-            , DigestAlgorithm SHA256
-            , DigestAlgorithm SHA384
-            , DigestAlgorithm SHA512
-            ]
+    cofactorKDFs =
+        [ KA_X963_KDF SHA1
+        , KA_X963_KDF SHA224
+        , KA_X963_KDF SHA256
+        , KA_X963_KDF SHA384
+        , KA_X963_KDF SHA512
+        ]
+
+    stdKDFs = cofactorKDFs ++
+        [ KA_HKDF SHA256
+        , KA_HKDF SHA384
+        , KA_HKDF SHA512
+        ]
 
 arbitraryEnvDev :: ContentEncryptionKey
                 -> Gen ([ProducerOfRI Gen], ConsumerOfRI Gen)
